@@ -1,7 +1,7 @@
 package Data::Clean::JSON;
 
 our $DATE = '2016-05-21'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,7 +21,7 @@ sub new {
     $opts{-circular} //= ['clone'];
     $opts{-obj}      //= ['unbless'];
 
-    $opts{'!recurse_object'} //= 1;
+    $opts{'!recurse_obj'} //= 1;
     $class->SUPER::new(%opts);
 }
 
@@ -46,7 +46,7 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.34 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2016-05-21.
+This document describes version 0.35 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2016-05-21.
 
 =head1 SYNOPSIS
 
@@ -88,6 +88,8 @@ default:
 
 =back
 
+Cleaning recurses into objects.
+
 Data that has been cleaned will probably not be convertible back to the
 original, due to information loss (for example, coderefs converted to string
 C<"CODE">).
